@@ -452,6 +452,8 @@ std::unordered_map<std::string, DataPackage::_rtde_type_variant> DataPackage::g_
   { "payload_inertia", vector6d_t() },
   { "script_control_line", uint32_t() },
   { "time_scale_source", int32_t() },
+  { "target_gravity", vector3d_t() },
+  { "target_base_acceleration", vector6d_t() },
 
   // NOT IN OFFICIAL DOCS
   { "tool_digital_output_mask", uint8_t() },
